@@ -5,6 +5,8 @@ import pandas as pd
 import requests
 import zipfile
 
+from raga.raga_schema import VideoDetectionObject
+
 
 logger = logging.getLogger(__name__)
 
@@ -12,21 +14,23 @@ logger = logging.getLogger(__name__)
 class FileUploadError(Exception):
     pass
 
+def check_key_value_existence(column_list, key, value):
+    return any(column.get(key) == value for column in column_list)
+
 def data_frame_extractor(test_df: pd.DataFrame):
-    dr = []
-    for index, row in test_df.iterrows():
-        df = {}
-        for column_name in test_df.columns:
-            element = row[column_name]
-            df[column_name] = element.get()
-        dr.append(df)
-    return pd.DataFrame(dr)
+    extracted_df = test_df.applymap(lambda element: element.get())
+    return extracted_df
 
 def make_arg(model_name, inference_col_name, embedding_col_name):
-    return [
-        {"customerColumnName": inference_col_name, "type": "inference", "model": model_name, "ref_col_name": ""},
-        {"customerColumnName": embedding_col_name, "type": "imageEmbedding", "model": model_name, "ref_col_name": ""}
+    payload = [
+        {"customerColumnName": "file_name", "type": "imageName", "modelName": "", "ref_col_name": ""},
+        {"customerColumnName": "coco_url", "type": "imageUri", "modelName": "", "ref_col_name": ""},
+        {"customerColumnName": "date_captured", "type": "timestamp", "modelName": "", "ref_col_name": ""},
+        {"customerColumnName": f"{inference_col_name}_{model_name}", "type": "inference", "modelName": model_name, "ref_col_name": ""},
     ]
+    if embedding_col_name:
+        payload.append({"customerColumnName": f"{embedding_col_name}_{model_name}", "type": "imageEmbedding", "modelName": model_name, "ref_col_name": ""})
+    return payload
 
 
 def upload_file(pre_signed_url, file_path, success_callback=None, failure_callback=None):
